Specificity values range from 0 to 100. Values of 0 indicate
intensity values are identical in all layers. Values of 100 indicate
intensity values are restricted to a single layer. Interpretation of
specificity values depends on the layers provided. If layers describe the
distribution of a species at different times of the year, specificity can
be interpreted as a measure of seasonality (i.e., 0 = stable year-round
occurrence in a cell, 100 = highly seasonal occurrence). If layers describe
space use by multiple individuals, specificity can be interpreted as a
measure of exclusivity (i.e., 0 = equal use of a cell by all individuals,
100 = exclusive use by one individual).
The number of layers with non-NA values is recorded to aid interpretation
of distributions. Ideally, n_layers values are identical in every cell,
indicating that users have knowledge of distributions over the same area in
every layer of their raster stack. When n_layers values are unequal, it
indicates that users have unequal knowledge of distributions in their
raster stack. Distributions are more likely to be misrepresented and
misinterpreted if cells do not contain intensity values in every layer.